pub struct DiffSection {
pub y_idx: usize,
pub height: usize,
pub kind: DiffSectionKind,
}Fields
y_idx: usizeThe y index that the diff section is at.
This is multiplied by the line height to get the y position.
So this can roughly be considered as the VLine of the start of this diff section, but it
isn’t necessarily convertible to a VLine due to jumping over empty code sections.
height: usizekind: DiffSectionKindTrait Implementations
Sourceimpl Clone for DiffSection
impl Clone for DiffSection
Sourcefn clone(&self) -> DiffSection
fn clone(&self) -> DiffSection
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for DiffSection
impl PartialEq for DiffSection
impl StructuralPartialEq for DiffSection